[−][src]Struct evdev::Switch
Implementations
impl Switch[src]
pub fn empty() -> Switch[src]
Returns an empty set of flags.
pub fn all() -> Switch[src]
Returns the set containing all flags.
pub fn bits(&self) -> u32[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<Switch>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> Switch[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub fn intersects(&self, other: Switch) -> bool[src]
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: Switch) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: Switch)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: Switch)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: Switch)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: Switch, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.
impl Switch[src]
pub fn number<T: FromPrimitive>(&self) -> T[src]
Given a bitflag with only a single flag set, returns the event code corresponding to that event. If multiple flags are set, the one with the most significant bit wins. In debug mode,