pub struct SynchronizationCode(pub u16);Available on Unix only.
A “synchronization” message type published by the kernel into the events stream.
Tuple Fields
0: u16Implementations
Sourceimpl SynchronizationCode
impl SynchronizationCode
Sourcepub const SYN_REPORT: Self
pub const SYN_REPORT: Self
Used to mark the end of a single atomic “reading” from the device.
Sourcepub const SYN_CONFIG: Self
pub const SYN_CONFIG: Self
Appears to be unused.
Sourcepub const SYN_MT_REPORT: Self
pub const SYN_MT_REPORT: Self
“Used to synchronize and separate touch events”
Sourcepub const SYN_DROPPED: Self
pub const SYN_DROPPED: Self
Ring buffer filled, events were dropped.